BFGraph: minHashResultIterator< HF > Struct Template Reference

BFGraph

Public Member Functions | Data Fields
minHashResultIterator< HF > Struct Template Reference

## Public Member Functions
| minHashResultIterator (const minHashIterator< HF > *p)
bool | operator== (const minHashResultIterator &o)
bool | operator!= (const minHashResultIterator &o)
minHashResultIterator & | operator++ ()
minHashResultIterator | operator++ (int)
const minHashResult & | operator* () const
const minHashResult * | operator-> () const

## Data Fields
const minHashIterator< HF > * | p
bool | invalid
int | pos
const int | p_pos
const char * | p_s

The documentation for this struct was generated from the following file:

- src/minHashIterator.hpp